@@ -1,4 +1,4 @@
-#' @importFrom officer fp_sign fp_cell fp_par fp_text fp_border
+#' @importFrom officer fp_cell fp_par fp_text fp_border
 complex_tabpart <- function( data, col_keys = names(data),
                              default_pr_text = fp_text(),
                              default_pr_par = fp_par(),
@@ -13,7 +13,7 @@ complex_tabpart <- function( data, col_keys = names(data),
   if( nrow(data) > 0 ){
 
     newcontent <- lapply(data[col_keys], function(x)
-      as_paragraph(as_chunk(x, formater = function(x) {
+      as_paragraph(as_chunk(x, formatter = function(x) {
         if( is.character(x) || is.factor(x) ) format_fun(x)
         else format(x, trim = TRUE)
 
